@@ -6,7 +6,7 @@ use XSLoader ();
 package Class::XSConstructor;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.011';
+our $VERSION   = '0.012';
 
 use Exporter::Tiny 1.000000 qw( mkopt );
 use Ref::Util 0.100 qw( is_plain_arrayref is_plain_hashref is_blessed_ref is_coderef is_plain_scalarref );
@@ -69,13 +69,13 @@ sub import {
 		}
 		
 		if (is_blessed_ref($spec{isa}) and $spec{isa}->can('compiled_check')) {
-			$type = $thing;
+			$type = $spec{isa};
 			$spec{isa} = $type->compiled_check;
 		}
 		elsif (is_blessed_ref($spec{isa}) and $spec{isa}->can('check')) {
 			# Support it for compatibility with more basic Type::API::Constraint
 			# implementations, but this will be slowwwwww!
-			$type = $thing;
+			$type = $spec{isa};
 			$spec{isa} = sub { !! $type->check($_[0]) };
 		}
 		
